<?php
/*
Plugin Name: MyBookTable Professional
Plugin URI: http://www.mybooktable.com
Description: Adds professional level features to MyBookTable. Requires the MyBookTable plugin.
Author: Castle Media Group
Version: 0.1.0
*/

define("MBTPRO_VERSION", "0.1.0");



function mbtpro_init() {
	add_filter('mbt_buybuttons', 'mbtpro_add_buybuttons');
	add_filter('mbt_style_directories', 'mbtpro_add_style_dir', 20);

	if(mbt_get_setting('pro_active')) {
		add_action('wp_update_plugins', 'mbtpro_update_check');
		add_filter('mbt_buybutton_settings', 'mbtpro_amazon_buybutton_settings');
		add_filter('mbt_buybutton_settings_save', 'mbtpro_amazon_buybutton_settings_save');
		add_filter('mbt_buybuttons', 'mbtpro_override_amazon_buybutton', 20);
	}
}



/*---------------------------------------------------------*/
/* Style Directory                                         */
/*---------------------------------------------------------*/

function mbtpro_add_style_dir($directories) {
	$directories[] = array('dir' => plugin_dir_path(__FILE__).'styles', 'url' => plugins_url('styles', __FILE__));
	return $directories;
}



/*---------------------------------------------------------*/
/* Extra Buy Buttons                                       */
/*---------------------------------------------------------*/

function mbtpro_add_buybuttons($buybuttons) {
	$buybuttons['cbd'] = array('name' => 'Christian Book Distributor', 'desc' => 'Christian Book Distributor Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['sba'] = array('name' => 'Signed by the Author', 'desc' => 'Signed by the Author Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['audible'] = array('name' => 'Audible.com', 'desc' => 'Audible.com Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['bnn'] = array('name' => 'Barnes and Noble', 'desc' => 'Barnes and Noble Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['bam'] = array('name' => 'Books-A-Million', 'desc' => 'Books-A-Million Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['bookbaby'] = array('name' => 'BookBaby', 'desc' => 'BookBaby Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['lifeway'] = array('name' => 'Lifeway', 'desc' => 'Lifeway Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['mardel'] = array('name' => 'Mardel', 'desc' => 'Mardel Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['smashwords'] = array('name' => 'Smashwords', 'desc' => 'Smashwords Buy Button', 'editor' => 'mbt_default_buybutton_editor', 'button' => 'mbt_default_buybutton_button');
	$buybuttons['universal'] = array('name' => 'Universal Buy Button', 'desc' => 'Universal Buy Button', 'editor' => 'mbtpro_universal_buybutton_editor', 'button' => 'mbtpro_universal_buybutton_button');
	return $buybuttons;
}

function mbtpro_universal_buybutton_editor($data, $id, $type) {
	echo('<input name="'.$id.'[type]" type="hidden" value="'.$data['type'].'">');
	echo('<b>'.$type['name'].':</b><br>');
	echo('Button Text: <input type="text" name="'.$id.'[text]" value="'.(isset($data['text'])?$data['text']:'').'"><br>');
	echo('Button Link: <input type="text" name="'.$id.'[value]" value="'.$data['value'].'">');
	echo('<p>Paste in the affiliate link URL for this item. <a href="'.admin_url('admin.php?page=mbt_help').'" target="_blank">Learn more about adding Buy Button links.</a></p>');
}

function mbtpro_universal_buybutton_button($data) {
	return apply_filters('mbt_custom_buybutton', empty($data['value']) ? '' : '<div class="mbt-book-buybutton"><a class="mbt-custom-buybutton" href="'.$data['value'].'" target="_blank">'.$data['text'].'</a></div>');
}

function mbtpro_paypal_buybutton_editor($data, $id, $type) {
	echo('<input name="'.$id.'[type]" type="hidden" value="'.$data['type'].'">');
	echo('<b>'.$type['name'].':</b><br><textarea name="'.$id.'[value]" cols="80">'.$data['value'].'</textarea>');
	echo('<p>Paste in the button code for this item. <a href="'.admin_url('admin.php?page=mbt_help').'" target="_blank">Learn more about creating PayPal buttons.</a></p>');
}

function mbtpro_paypal_buybutton_button($data) {
	return empty($data['value']) ? '' : '<div class="mbt-book-buybutton">'.$data['value'].'</div>';
}



/*---------------------------------------------------------*/
/* Amazon Affiliate Integration                            */
/*---------------------------------------------------------*/

function mbtpro_override_amazon_buybutton($buybuttons) {
	$buybuttons['amazon']['button'] = 'mbtpro_amazon_buybutton_button';
	return $buybuttons;
}

function mbtpro_amazon_buybutton_button($data, $type) {
	$id = mbt_get_amazon_AISN($data['value']);
	$tld = mbt_get_amazon_tld($data['value']);
	$affiliatecode = mbt_get_setting('amazon_buybutton_affiliate_code');
	$img = mbt_image_url($data['type'].'_button.png');
	$output = empty($id) ? '' : '<div class="mbt-book-buybutton"><a href="http://www.amazon.'.$tld.'/dp/'.$id.'?tag='.(empty($affiliatecode)?'mybooktable-20':$affiliatecode).'" target="_blank"><img src="'.$img.'" border="0" alt="Buy from '.$type['name'].'"/></a></div>';
	return apply_filters('mbt_'.$data['type'].'_buybutton', $output);
}

function mbtpro_amazon_buybutton_settings() {
?>
	<table class="form-table">
		<tbody>
			<tr valign="top">
				<th scope="row"><label for="mbt_amazon_buybutton_affiliate_code">Amazon/Kindle Affiliate Code</label></th>
				<td>
					<input type="text" name="mbt_amazon_buybutton_affiliate_code" id="mbt_amazon_buybutton_affiliate_code" value="<?php echo(mbt_get_setting('amazon_buybutton_affiliate_code')); ?>" class="regular-text">
					<p class="description">
						You can find your amazon affiliate tracking ID by visiting the your <a href="https://affiliate-program.amazon.com/gp/associates/network/main.html" target="_blank">Amazon Affiliate Homepage</a>. The code should be near the top left of the screen and will end in "-20" if you live in the United States of America.
					</p>
				</td>
			</tr>
		</tbody>
	</table>
<?php
}

function mbtpro_amazon_buybutton_settings_save() {
	if(isset($_REQUEST['mbt_amazon_buybutton_affiliate_code'])) {
		mbt_update_setting('amazon_buybutton_affiliate_code', $_REQUEST['mbt_amazon_buybutton_affiliate_code']);
	}
}



/*---------------------------------------------------------*/
/* API Interface                                           */
/*---------------------------------------------------------*/

function mbtpro_update_check() {
	global $wp_version;
	$api_key = mbt_get_setting('api_key');
	if(empty($api_key)) { return; }

	$to_send = array(
		'action' => 'basic_check',
		'version' => MBTPRO_VERSION,
		'api-key' => $api_key,
		'site' => get_bloginfo('url')
	);

	$options = array(
		'timeout' => ((defined('DOING_CRON') && DOING_CRON) ? 30 : 3),
		'body' => $to_send,
		'user-agent' => 'WordPress/'.$wp_version.'; '.get_bloginfo('url')
	);

	$raw_response = wp_remote_post('http://www.authormedia.com/plugins/mybooktable-pro/update-check', $options);

	if(is_wp_error($raw_response) || 200 != wp_remote_retrieve_response_code($raw_response)) { return false; }

	$response = maybe_unserialize(wp_remote_retrieve_body($raw_response));

	if(!is_array($response)) { return; }

	$new_version = $response['new_version'];
	$package = $response['package'];

	if(empty($new_version) or empty($response)) { return; }

	$plugin_folder = plugin_basename(dirname(dirname(__FILE__)));
	$data = (object) array(
		'slug' => $plugin_folder,
		'new_version' => $new_version,
		'url' => "http://www.mybooktable.com",
		'package' => $package
	);

	$plugin_transient = get_site_transient('update_plugins');
	$plugin_transient->response[$plugin_folder.'/mybooktable-pro.php'] = $data;
	set_site_transient('update_plugins', $plugin_transient);
}